Changelog - 2013
================

R17.5 / 2013-07-03
------------------

- new: add signals documentation
- new: add post_worker_init hook for workers
- new: try to use gunicorn.conf.py in current folder as the default
  config file.
- fix graceful timeout with the Eventlet worker
- fix: don't raise an error when closing the socket if already closed
- fix: fix --settings parameter for django application and try to find
  the django settings when using the ``gunicorn`` command.
- fix: give the initial global_conf to paster application
- fix: fix 'Expect: 100-continue' support on Python 3

0.17.4 / 2013-04-24
-------------------

- fix unix socket address parsing

0.17.3 / 2013-04-23
-------------------

- add systemd sockets support
- add ``python -m gunicorn.app.wsgiapp`` support
- improve logger class inheritance
- exit when the config file isn't found
- add the -R option to enable stdio inheritance in daemon mode
- don't close file descriptors > 3 in daemon mode
- improve STDOUT/STDERR logging
- fix pythonpath option
- fix pidfile creation on Python 3
- fix gevent worker exit
- fix ipv6 detection when the platform isn't supporting it

0.17.2 / 2013-01-07
-------------------

- optimize readline
- make imports errors more visiblle when loading an app or a logging
  class
- fix tornado worker: don't pass ssl options if there are none
- fix PEP3333: accept only bytetrings in the response body
- fix support on CYGWIN platforms

0.17.1 / 2013-01-05
-------------------

- add syslog facility name setting
- fix ``--version`` command line argument
- fix wsgi url_scheme for https
